..  Note to the editor: beware of implicit inline
    targets aliasing, keep global title different from all commands

=============================================================================
KeDiFa - KEy DIstribution FAcility
=============================================================================

Overview
========

A system to upload SSL keys for some nodes to securely download them.
